@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,23 +21,22 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: sql.php,v 1.1 2004/03/31 12:58:23 alec Exp $
+ *  $Id: sql.php,v 1.6 2004/04/12 19:24:25 alec Exp $
  */
-function microtime_diff($a, $b)
-{
-	list($a_usec, $a_sec) = explode(' ', $a);
-	list($b_usec, $b_sec) = explode(' ', $b);
-	return $b_sec - $a_sec + $b_usec - $a_usec;
-}
  
 $layout['pagetitle'] = 'SQL';
 
 if($query = $_POST['query'])
 {
-	$t = microtime();
+	$pagelimit = ( $_CONFIG['phpui']['sqlpanel_pagelimit'] ? $_CONFIG['lmsui']['sqlpanel_pagelimit'] : 50 );
+	$page = (! $_GET['page'] ? 1 : $_GET['page']); 
+	$start = ($page - 1) * $pagelimit;
+	$words = array('SELECT','EXPLAIN','SHOW','DESCRIBE','ANALYZE','CHECK','OPTIMIZE','REPAIR','VACUUM');
+
+	$t = getmicrotime();
 	$rows = $LMS->DB->Execute($query);
-	$duration = microtime_diff($t, microtime());
-	
+	$duration = getmicrotime() - $t;
+
 	if(sizeof($LMS->DB->errors)) 
 	{
 		$error['query'] = 'Zapytanie nie jest poprawne!';
@@ -46,22 +45,19 @@ if($query = $_POST['query'])
 		$SMARTY->display('sql.html');	
 		die;
 	}
-	
-	if( ! eregi('^SELECT',$query) && ! eregi('^EXPLAIN',$query))
-	{
-		$SMARTY->display('header.html');
-		$SMARTY->display('adminheader.html');
-		echo '<H1>SQL - Wyniki zapytania</H1>';		
-		echo '<B>Zapytanie dotyczyo '.$rows.' wiersza(y).</B><BR>';
-		printf('<B>Czas wykonania: %0.3f sek.</B>',$t);
-		$SMARTY->display('footer.html');
-		die;
-	}
+		
+	list($firstword) = explode(' ', trim($query));
 
-	unset($result);
-
-	switch($_CONFIG['database']['type'])
+	if( ! in_array(strtoupper($firstword), $words) )
 	{
+		$nrows = $rows;
+	} 
+	else
+	{
+		unset($result);
+
+		switch($_CONFIG['database']['type'])
+		{
 		case 'postgres':
 			$cols = pg_num_fields($LMS->DB->_result);
 			for($i=0; $i < $cols; $i++)
@@ -72,38 +68,48 @@ if($query = $_POST['query'])
 			for($i=0; $i < $cols; $i++)
 				$colnames[] = mysql_field_name($LMS->DB->_result, $i);
 		break;
+		case 'sqlite':
+			$cols = sqlite_num_fields($LMS->DB->_result);
+			for($i=0; $i < $cols; $i++)
+				$colnames[] = sqlite_field_name($LMS->DB->_result, $i);
+		break;
+		}
+
+		$i = 0;
+		while($row = $LMS->DB->_driver_fetchrow_assoc())
+		{
+			$i++;
+			if ( $i > $start && $i < ($start+$pagelimit+1) )
+			{
+				$result .= '<TR CLASS="LIGHT"><TD CLASS="BLEND">'.$i.'</TD>';
+				foreach($colnames as $column)	
+				{
+					$result .= '<TD>'.$row[$column].'</TD>';
+				}
+				$result .= '</TR>';
+			}
+		}
+		$nrows = $i;
 	}
 
-	$SMARTY->display('header.html');
-	$SMARTY->display('adminheader.html');
-	echo '<H1>SQL - Wyniki zapytania</H1>';		
-	echo '<P><TABLE CELLPADDING="3"><TR><TD CLASS="fall">';
-	echo '<TABLE CELLPADDING="3">';
-	echo '<TR CLASS="DARK">';
-	foreach($colnames as $column)	
-	{
-		echo "<TD ALIGN=\"center\"><B>$column</B></TD>";
-	}
-	echo '</TR>';
-	
-	while($row = $LMS->DB->_driver_fetchrow_assoc())
-	{
-		echo '<TR CLASS="LIGHT">';
-		foreach($colnames as $column)	
-		{
-			echo '<TD>'.$row[$column].'</TD>';
-		}
-		echo '</TR>';
-	}
-	
-	echo '</TABLE>';
-	echo '</TD></TR></TABLE></P>';
-	printf('<B>Czas wykonania: %0.3f sek.</B>',$t);
-	$SMARTY->display('footer.html');
-	die;
+	$SMARTY->assign('start', $start);
+	$SMARTY->assign('page', $page);
+	$SMARTY->assign('pagelimit', $pagelimit);
+	$SMARTY->assign('nrows', $nrows);
+	$SMARTY->assign('ncols', $cols+1);
+	$SMARTY->assign('colnames', $colnames);
+	$SMARTY->assign('executetime', $duration);
+	$SMARTY->assign('result', $result);
+	$layout['pagetitle'] = 'SQL - Wyniki zapytania';
 }
 
 $SMARTY->assign('query', $query);
-$SMARTY->display('sql.html');
 
-?>
\ No newline at end of file
+if($_GET['print'])
+	$SMARTY->display('sqlprint.html');
+else
+	$SMARTY->display('sql.html');
+
+?>
+
+
