@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Session.class.php,v 1.48 2004/04/01 12:31:57 alec Exp $
+ *  $Id: Session.class.php,v 1.50 2004/07/12 19:17:36 alec Exp $
  */
 
 class Session {
@@ -34,8 +34,8 @@ class Session {
 	var $last;
 	var $lastip;
 	var $error;
-	var $_version = '1.3.4 Terok';
-	var $_revision = '$Revision: 1.48 $';
+	var $_version = '1.3.6 Osiris';
+	var $_revision = '$Revision: 1.50 $';
 
 	function Session(&$DB,$timeout = 600)
 	{
@@ -47,9 +47,9 @@ class Session {
 			$loginform = $_POST['loginform'];
 		if(isset($loginform))
 		{
-			$this->login = $loginform[login];
-			$this->passwd = $loginform[pwd];
-			$_SESSION[session_timestamp] = time();
+			$this->login = $loginform['login'];
+			$this->passwd = $loginform['pwd'];
+			$_SESSION['session_timestamp'] = time();
 			writesyslog("Login attempt by ".$this->login,LOG_INFO);
 		}
 		elseif($this->DB->GetOne('SELECT COUNT(id) FROM admins') == 0)
@@ -57,41 +57,41 @@ class Session {
 			$this->islogged = TRUE;
 			$this->passwd = 'EMPTY';
 			$this->logname = 'nie zalogowany';
-			$_GET[m] = 'adminadd';
+			$_GET['m'] = 'adminadd';
 			return TRUE;
 		}
 		else
 		{
-			$this->login = $_SESSION[session_login];
-			$this->passwd = $_SESSION[session_passwd];
+			$this->login = $_SESSION['session_login'];
+			$this->passwd = $_SESSION['session_passwd'];
 		}
 		
 		if($this->VerifyPassword()&&$this->TimeOut($timeout)){
 			$this->islogged = TRUE;
 			$admindata = $this->DB->GetRow("SELECT id, name FROM admins WHERE login=?",array($this->login));
-			$this->id = $admindata[id];
-			$this->logname = $admindata[name];
-			$this->last = $_SESSION[session_last];
-			$this->lastip = $_SESSION[session_lastip];
+			$this->id = $admindata['id'];
+			$this->logname = $admindata['name'];
+			$this->last = $_SESSION['session_last'];
+			$this->lastip = $_SESSION['session_lastip'];
 			if(isset($loginform))
 			{
 				$admindata = $this->DB->GetRow("SELECT lastlogindate, lastloginip FROM admins WHERE id=?",array($this->id));
-				$this->last = $admindata[lastlogindate];
-				$this->lastip = $admindata[lastloginip];
+				$this->last = $admindata['lastlogindate'];
+				$this->lastip = $admindata['lastloginip'];
 				
-				$this->DB->Execute("UPDATE admins SET lastlogindate=?, lastloginip=? WHERE id=?",array(time(),$_SERVER[REMOTE_ADDR],$this->id));
+				$this->DB->Execute("UPDATE admins SET lastlogindate=?, lastloginip=? WHERE id=?",array(time(),$_SERVER['REMOTE_ADDR'],$this->id));
 				writesyslog("User ".$this->login." logged in",LOG_INFO);
 			}
-			$_SESSION[session_login] = $this->login;
-			$_SESSION[session_passwd] = $this->passwd;
-			$_SESSION[session_last] = $this->last;
-			$_SESSION[session_lastip] = $this->lastip;
+			$_SESSION['session_login'] = $this->login;
+			$_SESSION['session_passwd'] = $this->passwd;
+			$_SESSION['session_last'] = $this->last;
+			$_SESSION['session_lastip'] = $this->lastip;
 		}else{
 			$this->islogged = FALSE;
 			if(isset($loginform))
 			{
 				writesyslog("Bad password for ".$this->login,LOG_WARNING);
-				$this->DB->Execute("UPDATE admins SET failedlogindate=?, failedloginip=? WHERE login=?",array(time(),$_SERVER[REMOTE_ADDR],$this->login));
+				$this->DB->Execute("UPDATE admins SET failedlogindate=?, failedloginip=? WHERE login=?",array(time(),$_SERVER['REMOTE_ADDR'],$this->login));
 			}
 			$this->LogOut();
 		}
@@ -114,14 +114,14 @@ class Session {
 	
 	function TimeOut($timeout = 600)
 	{
-		if( (time()-$_SESSION[session_timestamp]) > $timeout )
+		if( (time() - $_SESSION['session_timestamp']) > $timeout )
 		{
-			$this->error="Przekroczye limit czasu bezczynnoci (".$timeout." sekund).";
+			$this->error = "Przekroczye limit czasu bezczynnoci (".$timeout." sekund).";
 			return FALSE;
 		}
 		else
 		{
-			$_SESSION[session_timestamp] = time();
+			$_SESSION['session_timestamp'] = time();
 			return TRUE;
 		}
 	}
