@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,25 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: language.php,v 1.5 2004/03/02 20:38:28 lexx Exp $
+ *  $Id: language.php,v 1.8 2004/08/17 14:52:25 lexx Exp $
  */
 
-$language = 'en';
-$langs = explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE']);
-foreach ($langs as $val) {
-    switch (substr($val, 0, 2)) {
-	case 'pl':
-            $language = 'pl';
-	    setlocale(LC_ALL, 'pl_PL');
-            break 2;
-        case 'en':
-	    $language = 'en';
-	    setlocale(LC_ALL, 'en_US');
-	    break 2;
-    }
-}
+// Plik do ustawiania locales i do translacji...
+// Chwilowo tutaj nie ma nic, naprawd nic, poprostu potrzebne do eksperymentw paru.
 
-bindtextdomain("lms", "$_LIB_DIR/locale");
-textdomain("lms");
+// ustawienie komunikatw syst. na polskie
+setlocale(LC_MESSAGES,'pl_PL');
+// ustawienie formatu czasu na polski
+setlocale(LC_TIME,'pl_PL');
+// kapitalizowanie literek
+setlocale(LC_CTYPE,'pl_PL');
 
 ?>
\ No newline at end of file
