@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: genfake.php,v 1.18 2004/07/23 10:24:11 alec Exp $
+ *  $Id: genfake.php,v 1.19 2004/08/16 11:23:19 lexx Exp $
  */
 
 // Nazwiska
@@ -1574,7 +1574,8 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 			$nodedata['ownerid'] = $id;
 			$nodedata['access'] = 1;
 			$nodedata['warning'] = 0;
-			$LMS->NodeAdd($nodedata);
+			$nodeid = $LMS->NodeAdd($nodedata);
+			$DB->Execute("UPDATE `nodes` SET `lastonline` = '".mt_rand(time()-2592000,time()+2592000)."' WHERE `id` = '".$nodeid."' ");
 		}
 		$startip ++;
 	}
@@ -1589,7 +1590,7 @@ if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
 		$prod = mt_rand(0,$sprod-1);
 		$LMS->NetDevAdd(array(
 			'name' => "SWITCH_".$i,
-			'location' => "",
+			'location' => $streets[mt_rand(0,$ssize-1)].' '.mt_rand(1,50),
 			'description' => "",
 			'producer' => $producer[$prod],
 			'model' => "10/100 Mbps Switch",
