@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: logout.php,v 1.21 2004/07/05 23:26:57 lukasz Exp $
+ *  $Id: logout.php,v 1.22 2004/07/08 19:26:38 alec Exp $
  */
 
-if($_GET['is_sure'] === 1) 
+if($_GET['is_sure'] == '1') 
 {
 	$SESSION->LogOut();
 	header('Location: ?m=welcome');
