@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,23 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.18 2004/05/28 07:12:36 alec Exp $
+ *  $Id: netdevmap.php,v 1.26 2004/08/25 19:31:12 alec Exp $
+ */
 
-                                 _
- _   ___      ____ _  __ _  __ _| |
-| | | \ \ /\ / / _` |/ _` |/ _` | |
-| |_| |\ V  V / (_| | (_| | (_| |_|
- \__,_| \_/\_/ \__,_|\__, |\__,_(_)
-                     |___/
-
-jak macie wasne pomysy, to nie modyfikujcie tego pliku a zrbcie tymczasowy
-nowy.
-
-*/
+function drawtext($image, $font, $x, $y, $text, $color, $bgcolor)
+{
+	imagestring($image, $font, $x + 1, $y + 1, $text, $bgcolor);
+	imagestring($image, $font, $x + 1, $y - 1, $text, $bgcolor);
+	imagestring($image, $font, $x - 1, $y + 1, $text, $bgcolor);
+	imagestring($image, $font, $x - 1, $y - 1, $text, $bgcolor);
+	imagestring($image, $font, $x, $y, $text, $color);
+}
 
 function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 {
-//	$fields[] = array( 'x' => -1, 'y' => 1 );
 	$fields[] = array( 'x' => 0, 'y' => 5 );
 	$fields[] = array( 'x' => 5, 'y' => 5 );     
 	$fields[] = array( 'x' => 5, 'y' => 0 );
@@ -46,6 +43,14 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 	$fields[] = array( 'x' => -5, 'y' => -5 );
 	$fields[] = array( 'x' => -5, 'y' => 0 );
 	$fields[] = array( 'x' => -5, 'y' => 5 );
+	$fields[] = array( 'x' => 5, 'y' => 10 );
+	$fields[] = array( 'x' => 10, 'y' => 10 );     
+	$fields[] = array( 'x' => 10, 'y' => 5 );
+	$fields[] = array( 'x' => 10, 'y' => -10 );
+	$fields[] = array( 'x' => 5, 'y' => -10 );
+	$fields[] = array( 'x' => -10, 'y' => -10 );
+	$fields[] = array( 'x' => -10, 'y' => 5 );
+	$fields[] = array( 'x' => -10, 'y' => 10 );
 
 	unset($nodefields);
 
@@ -134,16 +139,75 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 
 $layout['pagetitle'] = "Mapa pocze sieciowych";
 
+$start = sprintf('%d',$_GET['start']);
+	
 if($_GET['graph'] == "")
 {
+	makemap($DB,$map,$seen,$start);
+	foreach($map as $idx => $x)
+	{
+		if($minx == NULL)
+			$minx = $idx;
+		elseif($idx < $minx)
+			$minx = $idx;
+		
+		if($idx > $maxx)
+			$maxx = $idx;
+		foreach($x as $idy => $y)
+		{
+			if($miny == NULL)
+				$miny = $idy;
+			elseif($idy < $miny)
+				$miny = $idy;
+
+			if($idy > $maxy)
+				$maxy = $idy;
+		}
+	}
+
+	$widthx = $maxx - $minx;
+	$widthy = $maxy - $miny;
+	$cellw = 70;
+	$cellh = 30;
+	$celltmargin = 10;
+	$celllmargin = 10;
+	$imgwx = $cellw * ($widthx + 2);
+	$imgwy = $cellh * ($widthy + 2);
+
+	foreach($map as $idx => $x)
+	{
+		foreach($x as $idy => $device)
+		{
+			$celx = $idx - $minx;
+			$cely = $idy - $miny;
+			if(eregi('^n',$device))
+			{
+				$device = str_replace('n','',$device);
+				list($nodeid,$device) = explode('.',$device);
+				$nodemap[$nodeid]['x'] = (($celx * ($cellw)) + $celllmargin) +4;
+				$nodemap[$nodeid]['y'] = (($cely * ($cellh)) + $celltmargin) +4;
+				$nodemap[$nodeid]['id'] = $nodeid;
+			}
+			else
+			{
+				$devicemap[$device]['x'] = (($celx * ($cellw)) + $celllmargin) +4;
+				$devicemap[$device]['y'] = (($cely * ($cellh)) + $celltmargin) +4;
+				$devicemap[$device]['id'] = $device;
+			}
+		}
+	}
+	sort($nodemap);
+	sort($devicemap);
+
+	$SMARTY->assign('devicemap',$devicemap);
+	$SMARTY->assign('nodemap',$nodemap);
 	$SMARTY->assign('deviceslist',$DB->GetAll('SELECT id, name FROM netdevices ORDER BY name ASC'));
 	$SMARTY->assign('gderror', ! function_exists('imagepng'));
 	$SMARTY->assign('start',$_GET['start']);
 	$SMARTY->display('netdevmap.html');
-}
+} 
 else
 {	
-	$start = sprintf('%d',$_GET['start']);
 	makemap($DB,$map,$seen,$start);
 	foreach($map as $idx => $x)
 	{
@@ -238,24 +302,28 @@ else
 	}
 
 	$im_nd = imagecreatefrompng('img/netdev.png');
-	$im_n = imagecreatefrompng('img/node.png');
+	$im_n_unk = imagecreatefrompng('img/node_unk.png');
+	$im_n_off = imagecreatefrompng('img/node_off.png');
+	$im_n_on = imagecreatefrompng('img/node_on.png');
 
-//	print_r($nodemap);
-	
 	foreach($nodemap as $nodeid => $node)
 	{
 		$celx = $node['x'];
 		$cely = $node['y'];
 		$px = (($celx * ($cellw)) + $celllmargin);
 		$py = (($cely * ($cellh)) + $celltmargin);
-		imagecopy($im,$im_n,$px,$py,0,0,15,16);
-		$nodedata = $DB->GetRow('SELECT name, INET_NTOA(ipaddr) AS ip FROM nodes WHERE id=?',array($nodeid));
-//		imagestring($im, 1, $px + 15, $py - 8, $nodeid.' ('.$celx.','.$cely.')', $blue);
-		imagestring($im, 1, $px + 15, $py - 8, $nodedata['ip'], $blue);
-		imagestring($im, 1, $px + 15, $py + 2, $nodedata['name'], $black);
-	}
-				
+		$nodedata = $DB->GetRow('SELECT name, INET_NTOA(ipaddr) AS ip, lastonline FROM nodes WHERE id=?',array($nodeid));
+		if ($nodedata['lastonline']) {	
+			if ((time()-$nodedata['lastonline'])>$LMS->CONFIG['phpui']['lastonline_limit'])
+				imagecopy($im,$im_n_off,$px,$py,0,0,15,16);
+			else 
+				imagecopy($im,$im_n_on,$px,$py,0,0,15,16);
+		} else 
+			imagecopy($im,$im_n_unk,$px,$py,0,0,15,16);
 		
+		drawtext($im, 1, $px + 15, $py - 8, $nodedata['ip'], $blue, $lightbrown);
+		drawtext($im, 1, $px + 15, $py + 2, $nodedata['name'], $black, $lightbrown);
+	}
 
 	foreach($devicemap as $deviceid => $device)
 	{
@@ -264,15 +332,15 @@ else
 		$px = (($celx * ($cellw)) + $celllmargin);
 		$py = (($cely * ($cellh)) + $celltmargin);
 		imagecopy($im,$im_nd,$px,$py,0,0,16,16);
-//		imagestring($im, 1, $px + 20, $py - 8, $deviceid.' ('.$celx.','.$cely.')', $blue);
 		$deviceip = $DB->GetCol('SELECT INET_NTOA(ipaddr) FROM nodes WHERE ownerid=0 AND netdev=? ORDER BY ipaddr', array($deviceid));
-		if($deviceip[0]) imagestring($im, 1, $px + 20, $py - ($deviceip[1]?17:8), $deviceip[0], $blue);
-		if($deviceip[1]) imagestring($im, 1, $px + 20, $py - 8, $deviceip[1], $blue);
-		if($deviceip[2]) imagestring($im, 1, $px + 20, $py + 17, $deviceip[2], $blue);
-		if($deviceip[3]) imagestring($im, 1, $px + 20, $py + 26, $deviceip[3], $blue);
-		imagestring($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $darkred);
+		if($deviceip[0]) drawtext($im, 1, $px + 20, $py - ($deviceip[1]?17:8), $deviceip[0], $blue, $lightbrown);
+		if($deviceip[1]) drawtext($im, 1, $px + 20, $py - 8, $deviceip[1], $blue, $lightbrown);
+		if($deviceip[2]) drawtext($im, 1, $px + 20, $py + 17, $deviceip[2], $blue, $lightbrown);
+		if($deviceip[3]) drawtext($im, 1, $px + 20, $py + 26, $deviceip[3], $blue, $lightbrown);
+		drawtext($im, 3, $px + 20, $py + 2, $DB->GetOne('SELECT name FROM netdevices WHERE id=?',array($deviceid)), $darkred, $lightbrown);
+		$location=$DB->GetOne('SELECT location FROM netdevices WHERE id=?',array($deviceid));
+		drawtext($im, 2, $px + 20, $py + 18, $location, $green, $lightbrown);
 	}
-	
 		
 	imagepng($im);
 }
