@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentadd.php,v 1.4 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: paymentadd.php,v 1.5 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $payment = $_POST['payment'];
@@ -117,7 +117,6 @@ if(isset($payment))
 
 $layout['pagetitle'] = "Nowa opata staa";
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('payment',$payment);
 $SMARTY->display('paymentadd.html');
