@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketview.php,v 1.2 2004/07/02 11:24:52 alec Exp $
+ *  $Id: rtticketview.php,v 1.5 2004/07/11 20:55:50 alec Exp $
  */
 
 if(! $LMS->TicketExists($_GET['id']))
@@ -30,8 +30,14 @@ if(! $LMS->TicketExists($_GET['id']))
 	die;
 }
 
+if(! $LMS->GetAdminRightsRT($SESSION->id, 0, $_GET['id']))
+{
+	$SMARTY->display('noaccess.html');
+	die;
+}
+
 $ticket = $LMS->GetTicketContents($_GET['id']);
-$layout['pagetitle'] = 'Zgoszenie #'.$ticket['ticketid'].' - '.$ticket['subject'];
+$layout['pagetitle'] = 'Zgoszenie Nr '.sprintf("%06d",$ticket['ticketid']);
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
