@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.6 Osiris
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,23 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffdelete.php,v 1.15 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: tariffdelete.php,v 1.19 2004/02/21 19:38:17 lukasz Exp $
  */
 
-if(!$LMS->GetUsersWithTariff($_GET[id])&&$_GET[is_sure]="1")
-	$LMS->TariffDelete($_GET[id]);	
+if(!$LMS->GetUsersWithTariff($_GET['id'])&&$_GET['is_sure']="1")
+	$LMS->TariffDelete($_GET['id']);	
 
 header("Location: ?m=tarifflist");
 die;
 
-/*
- * $Log: tariffdelete.php,v $
- * Revision 1.15  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.14  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
\ No newline at end of file
