@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: upgrade01.php,v 1.8 2004/03/03 07:55:00 alec Exp $
+ *  $Id: upgrade01.php,v 1.9 2004/08/26 17:18:31 alec Exp $
  */
 
 $SMARTY->display('header.html');
@@ -34,7 +34,7 @@ foreach($users as $idx => $row)
 {
 	echo $row['lastname']." ".$row['name'].": ";
 	echo "taryfa: '".$tariffs[$row['tariff']]['name']."'... ";
-	$LMS->AddAssignment(array('tariffid' => $row['tariff'], 'at' => $row['payday'], 'userid' => $row['id'], 'period' => 1, 'invoice' => 0));
+	$LMS->DB->Execute('INSERT INTO assignments (tariffid, at, userid, period) VALUES (?,?,?,1)', array($row['tariff'], $row['payday'], $row['id']));
 	echo "ok.\n";
 }
 
