@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userinfo.php,v 1.35 2004/03/14 20:28:44 lukasz Exp $
+ *  $Id: userinfo.php,v 1.36 2004/04/17 17:00:47 chilek Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
@@ -38,6 +38,8 @@ if($LMS->UserExists($_GET['id']) == 0)
 
 $userinfo = $LMS->GetUser($_GET['id']);
 $assigments = $LMS->GetUserAssignments($_GET['id']);
+$usergroups = $LMS->UsergroupGetForUser($_GET['id']);
+$otherusergroups = $LMS->GetGroupNamesWithoutUser($_GET['id']);
 $balancelist = $LMS->GetUserBalanceList($_GET['id']);
 $usernodes = $LMS->GetUserNodes($_GET['id']);
 $tariffs = $LMS->GetTariffs();
@@ -52,6 +54,8 @@ $SMARTY->assign(
 			'usernodes' => $usernodes,
 			'balancelist' => $balancelist,
 			'assignments' => $assigments,
+			'usergroups' => $usergroups,
+			'otherusergroups' => $otherusergroups,
 			'error' => $error,
 			'userinfo' => $userinfo,
 			'tariffs' => $tariffs
